@@ -83,30 +83,29 @@ def copy(fromFileOrFolder: str, toFileOrFolder: str):
     if os.path.isfile(fromFileOrFolder):
         fromFile = fromFileOrFolder
         toFile = toFileOrFolder
-        makeFolder(getParentFolder(toFile))
+        makeFolder(os.path.dirname(toFile))
         shutil.copyfile(fromFile, toFile)
     elif os.path.isdir(fromFileOrFolder):
         fromFolder = fromFileOrFolder
         toFolder = toFileOrFolder
-        makeFolder(getParentFolder(toFolder))
+        makeFolder(os.path.dirname(toFolder))
         shutil.copytree(fromFolder, toFolder)
 
 
-def getParentFolder(fileOrFolder: str, level: int = 1):
-    result = fileOrFolder
-    while level > 0:
-        level -= 1
-        result = os.path.dirname(result)
-    return result
-
-
 def getFileExtName(file: str):
-    return file[file.rfind('.') + 1:].lower()
+    '''返回文件扩展名（不包含.）'''
+    if "." in file:
+        return file[file.rfind('.') + 1:].lower()
+    else:
+        return None
 
 
 def getFileBaseName(file: str):
     fileName = os.path.basename(file)
-    return fileName[:fileName.rfind(".")]
+    if "." in fileName:
+        return fileName[:fileName.rfind(".")]
+    else:
+        return fileName
 
 
 def getFileList(folder: str):
@@ -169,7 +168,14 @@ def getAllFileAndFolderList(folder: str):
 
 
 def getFileMD5(file: str):
-    data = readBinFile(file)
+    return getDataMD5(readBinFile(file))
+
+
+def getStrMD5(content: str):
+    return getDataMD5(content.encode())
+
+
+def getDataMD5(data: bytes):
     return hashlib.md5(data).hexdigest()
 
 
@@ -177,7 +183,7 @@ def getFileCRC(file: str):
     return getDataCRC(readBinFile(file))
 
 
-def getContentCRC(content: str):
+def getStrCRC(content: str):
     return getDataCRC(content.encode())
 
 
@@ -185,8 +191,8 @@ def getDataCRC(data: bytes):
     return hex(binascii.crc32(data))[2:].zfill(8)
 
 
-def getClassFullName(classItem: Any):
-    return getattr(classItem, '__module__') + '.' + getattr(classItem, '__name__')
+def getClassFullName(clazz: type):
+    return f"{clazz.__module__}.{clazz.__name__}"
 
 
 def makeTempWorkspace(clearOneDayBefore: bool = True):
